@@ -18,11 +18,12 @@ from jsonschema import validate
 
 from mockintosh import configs
 from mockintosh.exceptions import UnrecognizedConfigFileFormat
-from mockintosh.methods import _detect_engine, _nostderr
+from mockintosh.methods import _detect_engine, _nostderr, _import_from
 from mockintosh.recognizers import PathRecognizer, HeadersRecognizer, QueryStringRecognizer
 from mockintosh.servers import HttpServer
+from mockintosh.handlers import Request, Response  # noqa: F401
 
-__version__ = "0.0"
+__version__ = "0.1"
 __location__ = path.abspath(path.dirname(__file__))
 
 
@@ -64,6 +65,8 @@ class Definition():
 
     def analyze(self):
         for service in self.data['services']:
+            if 'endpoints' not in service:
+                continue
             for endpoint in service['endpoints']:
                 endpoint['params'] = {}
                 endpoint['context'] = OrderedDict()
@@ -105,7 +108,19 @@ def get_schema():
     return schema
 
 
-def run(source, is_file=True, debug=False):
+def import_interceptors(interceptors):
+    imported_interceptors = []
+    if interceptors is not None:
+        if 'unittest' in sys.modules.keys():
+            tests_dir = path.join(__location__, '../tests')
+            sys.path.append(tests_dir)
+        for interceptor in interceptors:
+            module, name = interceptor[0].rsplit('.', 1)
+            imported_interceptors.append(_import_from(module, name))
+    return imported_interceptors
+
+
+def run(source, is_file=True, debug=False, interceptors=()):
     schema = get_schema()
 
     if 'unittest' in sys.modules.keys():
@@ -118,7 +133,7 @@ def run(source, is_file=True, debug=False):
 
     try:
         definition = Definition(source, schema, is_file=is_file)
-        http_server = HttpServer(definition, debug=debug)
+        http_server = HttpServer(definition, debug=debug, interceptors=interceptors)
     except Exception:
         logging.exception('Mock server loading error:')
         with _nostderr():
@@ -140,9 +155,12 @@ def initiate():
     ap.add_argument('-d', '--debug', help='Enable Tornado Web Server\'s debug mode', action='store_true')
     ap.add_argument('-q', '--quiet', help='Less logging messages, only warnings and errors', action='store_true')
     ap.add_argument('-v', '--verbose', help='More logging messages, including debug', action='store_true')
+    ap.add_argument('-i', '--interceptor', help='A list of interceptors to be called in <package>.<module>.<function> format.', action='append', nargs='+')
     ap.add_argument('-l', '--logfile', help='Also write log into a file', action='store')
     args = vars(ap.parse_args())
 
+    interceptors = import_interceptors(args['interceptor'])
+
     fmt = "[%(asctime)s %(name)s %(levelname)s] %(message)s"
     if args['quiet']:
         logging.basicConfig(level=logging.WARNING, format=fmt)
@@ -156,4 +174,4 @@ def initiate():
         handler.setFormatter(logging.Formatter(fmt))
         logging.getLogger('').addHandler(handler)
 
-    run(args['source'], debug=args['debug'])
+    run(args['source'], debug=args['debug'], interceptors=interceptors)
